package {{ cookiecutter.__mvn_package }}.rest.controller;

import cn.dev33.satoken.annotation.SaCheckPermission;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.extension.plugins.pagination.PageDTO;
import java.io.Serializable;
import java.util.List;

import {{ cookiecutter.__mvn_package }}.rest.api.ApiController;
import {{ cookiecutter.__mvn_package }}.rest.api.R;
import {{ cookiecutter.__mvn_package }}.rest.entity.Page;
import {{ cookiecutter.__mvn_package }}.rest.service.PageService;
import io.swagger.v3.oas.annotations.Operation;
import io.swagger.v3.oas.annotations.Parameter;
import io.swagger.v3.oas.annotations.media.Schema;
import io.swagger.v3.oas.annotations.responses.ApiResponse;
import io.swagger.v3.oas.annotations.tags.Tag;
import org.springframework.lang.Nullable;
import org.springframework.web.bind.annotation.*;

/**
 * 页面表(Page)表控制层.
 *
 * @author zweiandlen
 * @since 2025-05-26 14:08:36
 */
@Tag(name = "标准接口", description = "由表结构自动生成")
@RestController
@RequestMapping("db/tPage")
public class PageController extends ApiController {
  /** 服务对象. */
  private final PageService tPageService;

  public PageController(PageService tPageService) {
    this.tPageService = tPageService;
  }

  /**
   * 分页查询所有数据.
   *
   * @param page 分页对象
   * @param tPage 查询实体
   * @return 分页数据
   */
  @Operation(
      summary = "页面表 - 分页查询所有数据",
      parameters = {
        @Parameter(name = "page", description = "分页对象"),
        @Parameter(name = "tPage", description = "查询实体"),
      },
      responses = @ApiResponse(description = "分页数据"),
      description = "size=-1时查询所有数据，orders配合asc排序")
  @GetMapping
  @SaCheckPermission("db:rest:get")
  public R selectAll(@Nullable PageDTO<Page> page, @Nullable Page tPage) {
    return success(this.tPageService.page(page, new QueryWrapper<>(tPage)));
  }

  /**
   * 通过主键查询单条数据.
   *
   * @param id 主键
   * @return 单条数据
   */
  @Operation(
      summary = "页面表 - 通过主键查询单条数据",
      parameters = {
        @Parameter(name = "id", description = "主键", schema = @Schema(type = "string")),
      },
      responses = @ApiResponse(description = "单条数据"))
  @GetMapping("{id}")
  @SaCheckPermission("db:rest:get")
  public R selectOne(@PathVariable Serializable id) {
    return success(this.tPageService.getById(id));
  }

  /**
   * 新增数据.
   *
   * @param page 实体对象
   * @return 新增结果
   */
  @Operation(
      summary = "页面表 - 新增数据",
      parameters = {
        @Parameter(name = "page", description = "实体对象"),
      },
      responses = @ApiResponse(description = "新增结果"))
  @PostMapping
  @SaCheckPermission("db:rest:post")
  public R insert(@RequestBody Page page) {
    return success(this.tPageService.save(page));
  }

  /**
   * 批量新增数据.
   *
   * @param pages 实体对象
   * @return 新增结果
   */
  @Operation(
      summary = "页面表 - 批量新增数据",
      parameters = {
        @Parameter(name = "pages", description = "实体对象"),
      },
      responses = @ApiResponse(description = "新增结果"))
  @PostMapping("s")
  @SaCheckPermission("db:rest:post")
  public R inserts(@RequestBody List<Page> pages) {
    return success(this.tPageService.saveBatch(pages));
  }

  /**
   * 修改数据.
   *
   * @param page 实体对象
   * @return 修改结果
   */
  @Operation(
      summary = "页面表 - 修改数据",
      parameters = {@Parameter(name = "page", description = "实体对象")},
      responses = @ApiResponse(description = "修改结果"),
      description = "不存在的对象会新增")
  @PutMapping
  @SaCheckPermission("db:rest:put")
  public R update(@RequestBody Page page) {
    return success(this.tPageService.saveOrUpdate(page));
  }

  /**
   * 批量修改数据.
   *
   * @param pages 实体对象
   * @return 修改结果
   */
  @Operation(
      summary = "页面表 - 批量修改数据",
      parameters = {@Parameter(name = "pages", description = "实体对象")},
      responses = @ApiResponse(description = "修改结果"),
      description = "不存在的对象会新增")
  @PutMapping("s")
  @SaCheckPermission("db:rest:put")
  public R updates(@RequestBody List<Page> pages) {
    return success(this.tPageService.saveOrUpdateBatch(pages));
  }

  /**
   * 删除数据.
   *
   * @param idList 主键结合
   * @return 删除结果
   */
  @Operation(
      summary = "页面表 - 删除数据",
      parameters = {
        @Parameter(name = "idList", description = "主键结合", schema = @Schema(type = "string"))
      },
      responses = @ApiResponse(description = "删除结果"),
      description = "主键用逗号拼接")
  @DeleteMapping
  @SaCheckPermission("db:rest:del")
  public R delete(@RequestParam("idList") List<Long> idList) {
    return success(this.tPageService.removeByIds(idList));
  }
}
