package {{ cookiecutter.__mvn_package }}.rest.entity;

import com.baomidou.mybatisplus.annotation.*;
import com.baomidou.mybatisplus.extension.activerecord.Model;
import com.baomidou.mybatisplus.extension.handlers.JacksonTypeHandler;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.databind.JsonNode;
import com.fasterxml.jackson.databind.annotation.JsonSerialize;
import com.fasterxml.jackson.databind.ser.std.ToStringSerializer;
import io.swagger.v3.oas.annotations.media.Schema;
import java.io.Serializable;
import java.time.OffsetDateTime;
import lombok.Data;
import lombok.EqualsAndHashCode;
{% if cookiecutter.platform == "postgis" -%}
import ltd.llvy.postgis.handler.JsonbTypeHandler;
{% endif %}
import org.apache.ibatis.type.JdbcType;

/**
 * 页面表(Page)表实体类.
 *
 * @author zweiandlen
 * @since 2025-05-26 14:08:36
 */
@Schema(description = "页面表")
@EqualsAndHashCode(callSuper = true)
@TableName(autoResultMap = true)
@Data
public class Page extends Model<Page> {
  // ID
  @Schema(description = "ID", type = "string")
  @JsonSerialize(using = ToStringSerializer.class)
  private Long id;

  // 内容
  @Schema(description = "内容")
  {% if cookiecutter.platform == "postgis" -%}
  @TableField(typeHandler = JsonbTypeHandler.class)
  {% else %}
  @TableField(typeHandler = JacksonTypeHandler.class)
  {% endif %}
  private JsonNode content;

  // 描述
  @Schema(description = "描述")
  private String description;

  // 乐观锁
  @Schema(description = "乐观锁")
  @Version
  private Integer version;

  // 逻辑删除
  @Schema(description = "逻辑删除")
  @TableLogic
  private Long deleteTime;

  // 创建时间
  @Schema(description = "创建时间")
  @JsonProperty(access = JsonProperty.Access.READ_ONLY)
  {% if cookiecutter.platform == "postgis" -%}
  @TableField(fill = FieldFill.INSERT, jdbcType = JdbcType.OTHER)
  {% else %}
  @TableField(fill = FieldFill.INSERT, jdbcType = JdbcType.DATETIMEOFFSET)
  {% endif %}
  private OffsetDateTime createTime;

  // 修改时间
  @Schema(description = "修改时间")
  @JsonProperty(access = JsonProperty.Access.READ_ONLY)
  {% if cookiecutter.platform == "postgis" -%}
  @TableField(fill = FieldFill.INSERT_UPDATE, jdbcType = JdbcType.OTHER)
  {% else %}
  @TableField(fill = FieldFill.INSERT_UPDATE, jdbcType = JdbcType.DATETIMEOFFSET)
  {% endif %}
  private OffsetDateTime updateTime;

  // 创建人
  @Schema(description = "创建人")
  @JsonProperty(access = JsonProperty.Access.READ_ONLY)
  @TableField(fill = FieldFill.INSERT)
  private String createBy;

  // 修改人
  @Schema(description = "修改人")
  @JsonProperty(access = JsonProperty.Access.READ_ONLY)
  @TableField(fill = FieldFill.INSERT_UPDATE)
  private String updateBy;

  /**
   * 获取主键值.
   *
   * @return 主键值
   */
  @Override
  public Serializable pkVal() {
    return this.id;
  }
}
